# MYSQL CREDENTIALS
mysql_user = "root"
mysql_pass = "ClickHouse_MySQL_P@ssw0rd"

# Dremio CREDENTIALS
dremio_user = "user"
dremio_pass = "ClickHouse_Dremio_P@ssw0rd"

# POSTGRES CREDENTIALS
pg_user = "postgres"
pg_pass = "ClickHouse_PostgreSQL_P@ssw0rd"
pg_db = "postgres"

# MINIO CREDENTIALS
minio_access_key = "minio"
minio_secret_key = "ClickHouse_Minio_P@ssw0rd"

# MONGODB CREDENTIALS
mongo_user = "root"
mongo_pass = "ClickHouse_MongoDB_P@ssw0rd"

# ODBC CREDENTIALS
odbc_mysql_uid = "root"
odbc_mysql_db = "clickhouse"

odbc_psql_db = "postgres"
odbc_psql_user = "postgres"

# KAFKA CREDENTIALS
kafka_sasl_user = "admin"
kafka_sasl_pass = "ClickHouse_Kafka_P@ssw0rd"

# NATS CREDENTIALS
nats_user = "clickhouse"
nats_pass = "ClickHouse_NATS_P@ssw0rd"

# ARROWFLIGHT CREDENTIALS
arrowflight_user = "admin"
arrowflight_pass = "ClickHouse_ArrowFlight_P@ssw0rd"
